package net.knarcraft.placeholdersigns.container;

import org.bukkit.Location;
import org.bukkit.block.sign.Side;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Map;

/**
 * A sign containing one or more placeholders
 */
public final class PlaceholderSign {

    private final @NotNull Location location;
    private final @NotNull Map<Side, Map<Integer, String>> placeholders;
    private @Nullable Integer updateDelay;

    /**
     * Instantiates a new placeholder sign
     *
     * @param location     <p>The location of the sign</p>
     * @param placeholders <p>The original placeholders typed on the sign</p>
     * @param updateDelay  <p>The delay in ticks between each time this sign's placeholders are updated</p>
     */
    public PlaceholderSign(@NotNull Location location, @NotNull Map<Side, Map<Integer, String>> placeholders,
                           @Nullable Integer updateDelay) {
        this.location = location;
        this.placeholders = placeholders;
        this.updateDelay = updateDelay;
    }

    /**
     * Gets the location of this placeholder sign
     *
     * @return <p>The location of this placeholder sign</p>
     */
    @NotNull
    public Location getLocation() {
        return location;
    }

    /**
     * Gets the placeholders stored on this sign
     *
     * @return <p>The stored placeholders</p>
     */
    @NotNull
    public Map<Side, Map<Integer, String>> getPlaceholders() {
        return placeholders;
    }

    /**
     * Gets the update delay for this placeholder sign
     *
     * @return <p>The update delay</p>
     */
    @Nullable
    public Integer getUpdateDelay() {
        return updateDelay;
    }

    /**
     * Sets the update delay for this placeholder sign
     *
     * @param updateDelay <p>The new update delay</p>
     */
    public void setUpdateDelay(@Nullable Integer updateDelay) {
        this.updateDelay = updateDelay;
    }

    @Override
    public boolean equals(@NotNull Object object) {
        if (object instanceof PlaceholderSign otherSign) {
            return this.location.equals(otherSign.location);
        }
        return false;
    }

}
