package net.knarcraft.placeholdersigns.util;

import org.bukkit.block.Sign;
import org.bukkit.block.sign.Side;
import org.bukkit.block.sign.SignSide;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;

public final class SignSideHelper {

    private SignSideHelper() {

    }

    /**
     * Gets the side of the given sign the given player is standing on (which side the player clicked)
     *
     * @param sign   <p>The sign to check</p>
     * @param player <p>The player to check</p>
     * @return <p>The side of the sign the player is standing on</p>
     */
    @NotNull
    public static Side getSide(@NotNull Sign sign, @NotNull Player player) {
        SignSide standingOn = sign.getTargetSide(player);
        return sign.getSide(Side.FRONT).equals(standingOn) ? Side.FRONT : Side.BACK;
    }

    /**
     * Gets the opposite sign side from the given sign side
     *
     * @param side <p>The side to get the opposite of</p>
     * @return <p>The opposite side</p>
     */
    @NotNull
    public static Side getOpposite(@NotNull Side side) {
        return side == Side.FRONT ? Side.BACK : Side.FRONT;
    }

}
